# hyperspace-rpc

[![Build Status](https://drone.autonomic.zone/api/badges/hyperpy/hyperspace-rpc/status.svg)](https://drone.autonomic.zone/hyperpy/hyperspace-rpc)

## Raw RPC layer for Hyperspace

## Install

```sh
$ pip install hyperspace-rpc
```

## Example

See [hyperpy/hyperspace-client](https://github.com/hyperpy/hyperspace-client).
